@@ -1,5 +1,7 @@
-sample.size.calc <- function(start_n,itmax=10,nmax=600,powtarget=.825,powmargin=.025,posterior,g.m,p.sd,
-                             statistic,Amat=0L,exact=0L,difmin=0L,effectsize=FALSE,alpha=.05){
+sample.size.calc <- function(start_n=20,itmax=10,nmax=600,powtarget=.825,powmargin=.025,
+                             posterior,g.m,p.sd,
+                             statistic,Amat=0L,exact=0L,difmin=0L,effectsize=FALSE,
+                             alpha=.05){
   it=0; power.out=0
   Npower.l <- matrix(NA,ncol=2,nrow=itmax)
   colnames(Npower.l) <- c("n per group","Power")
@@ -27,16 +29,17 @@ sample.size.calc <- function(start_n,itmax=10,nmax=600,powtarget=.825,powmargin=
     Npower <- sum(nF)                   #actual sample size after equal groups
 
     #null distribution = F scores for original dataset
-    H0 <- prior.predictive.check(n=nF,posterior=posterior,obs=FALSE,
-                                 statistic=statistic,Amat=Amat,exact=exact,difmin=difmin,effectsize=effectsize)
+
+    H0 <- suppressWarnings(prior.predictive.check(n=nF,posterior=posterior,obs=FALSE,
+                                 statistic=statistic,Amat=Amat,exact=exact,difmin=difmin,effectsize=effectsize))
     #rejection value is max 5% of H0
     F_sim.H0 <- H0$F_sim
     rej.value <- quantile(F_sim.H0, 1-alpha)
 
     #alternative distr. = F scores when all group means are equal (value = general mean original)
     #the pooled SD of the y-data is that of the original posterior
-    Ha <- prior.predictive.check(n=nF,posterior=cbind(matrix(g.m,nrow=lFps,ncol=p),rep(p.sd,lFps)),
-                                 obs=FALSE,statistic=statistic,Amat=Amat,exact=exact,difmin=difmin,effectsize=effectsize)
+    Ha <- suppressWarnings(prior.predictive.check(n=nF,posterior=cbind(matrix(g.m,nrow=lFps,ncol=p,byrow=TRUE),rep(p.sd,lFps)),
+                                 obs=FALSE,statistic=statistic,Amat=Amat,exact=exact,difmin=difmin,effectsize=effectsize))
 
     #power, proportion F's more extreme than rej value based on null distribution (F's original)
     F_sim.Ha <- Ha$F_sim
@@ -70,4 +73,5 @@ sample.size.calc <- function(start_n,itmax=10,nmax=600,powtarget=.825,powmargin=
   hist(F_sim.H0,freq=FALSE,col=rgb(1,0,0,1/4),border=rgb(1,0,0,1/2),main="",xlab=expression(bar(F))) #null with true effect
   hist(F_sim.Ha,freq=FALSE,col=rgb(0,0,1,1/4),border=rgb(0,0,1,1/2),add=TRUE) #H1, means equal
   abline(v=rej.value,col=rgb(1,0,1,1/2),lwd=2)
-  return(Npower.l[1:it,])}
+  return(list(sampcalc=Npower.l[1:it,]))
+  }
